#
# spec file for package python-fs
#
# Copyright (c) 2020 SUSE LLC
# Copyright (c) 2016 LISA GmbH, Bingen, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%bcond_without python2
Name:           python-fs
Version:        2.4.11
Release:        bp155.2.9
Summary:        Python's filesystem abstraction layer
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/PyFilesystem/pyfilesystem2
Source:         https://files.pythonhosted.org/packages/source/f/fs/fs-%{version}.tar.gz
Source1:        https://raw.githubusercontent.com/PyFilesystem/pyfilesystem2/master/tests/conftest.py
BuildRequires:  %{python_module appdirs >= 1.4.3}
BuildRequires:  %{python_module psutil}
BuildRequires:  %{python_module pyftpdlib}
BuildRequires:  %{python_module pysendfile}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module pytz}
BuildRequires:  %{python_module scandir >= 1.5}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six >= 1.10.0}
BuildRequires:  %{python_module typing >= 3.6}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-appdirs >= 1.4.3
Requires:       python-psutil
Requires:       python-pytz
Requires:       python-setuptools
Requires:       python-six >= 1.10.0
Requires:       python-typing >= 3.6
Recommends:     python-pyftpdlib
BuildArch:      noarch
%if %{with python2}
BuildRequires:  python-backports.os >= 0.1
BuildRequires:  python-enum34 >= 1.1.6
BuildRequires:  python-mock
%endif
%ifpython2
Requires:       python-backports.os >= 0.1
%endif
%if %{python_version_nodots} < 34
Requires:       python-enum34 >= 1.1.6
Recommends:     python-pysendfile
%endif
%if %{python3_version_nodots} < 35
Recommends:     python-scandir >= 1.5
%endif
%python_subpackages

%description
PyFilesystem is an abstraction layer for filesystems. In the same way that
Python's file-like objects provide a common way of accessing files,
PyFilesystem provides a common way of accessing entire filesystems. You can
write platform-independent code to work with local files, that also works with
any of the supported filesystems (zip, ftp, S3 etc.).

%prep
%setup -q -n fs-%{version}
sed -i -e 's:~=:>=:g' setup.py
cp %{SOURCE1} tests/

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=en_US.UTF-8
export PYTHONDONTWRITEBYTECODE=1
%pytest

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/*

%changelog
* Mon Apr 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build wihtout python2
* Thu Sep 12 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.4.11:
  * Restored fs.path import
  * Fixed potential race condition in makedirs. Fixes #310
  * Added missing methods to WrapFS. Fixed #294
  * MemFS now immediately releases all memory it holds when close() is called, rather than when it gets garbage collected. Closes issue #308.
  * FTPFS now translates EOFError into RemoteConnectionError. Closes #292
  * Added automatic close for filesystems that go out of scope. Fixes #298
  * Fixed broken WrapFS.movedir #322
  * Added geturl for TarFS and ZipFS for 'fs' purpose. NoURL for 'download' purpose.
  * Added helpful root path in CreateFailed exception #340
- remove patch more-relaxed-requirements.patch replaced by sed
* Fri Jul 26 2019 pgajdos@suse.com
- version update to 2.4.8
  * geturl will return URL with user/password if needed @zmej-serow
  * Flag to OSFS to disable env var expansion
  * Implemented geturl in FTPFS @zmej-serow
- modified patches
  %% more-relaxed-requirements.patch (refreshed)
* Thu May 16 2019 ranand@suse.com
  Update to 2.4.5
  Fixes:
  * Restored deprecated setfile method with deprecation warning
  to change to writefile
  * Fixed exception when a tarfile contains a path called '.'
  * Made TarFS directory loading lazy
* Fri Mar  1 2019 John Vandenberg <jayvdb@gmail.com>
- Remove unnecessary bcond_without test
- Simplifed build dependencies on scandir and typing
- Fix compatibility Requires for older Python which were using incorrect
  comparisons with python_version_nodots, and incorrectly used Recommends
- Update to v2.4.4
  * OSFS fail in nfs mounts
- from 2.4.3
  * Fixed broken "case_insensitive" check
  * Fixed Windows test fails
- from 2.4.2
  * Fixed exception when Python runs with -OO
- from 2.4.1
  * Fixed hash method missing from WrapFS
- from 2.4.0
  * Added exclude and filter_dirs arguments to walk
  * Micro-optimizations to walk
- from 2.3.1
  * Add encoding check in OSFS.validatepath
- from 2.3.0
  * IllegalBackReference had mangled error message
  * Added FS.hash method
* Fri Jan 25 2019 Todd R <toddrme2178@gmail.com>
- Update to version 2.2.1
  + Fixed
  * `Registry.install` returns its argument.
- Update to version 2.2.0
  * A few methods have been renamed for greater clarity (but functionality remains the same).
    The old methods are now aliases and will continue to work, but will
    issue a deprecation warning via the `warnings` module.
    Please update your code accordingly.
    > `getbytes` -> `readbytes`
    > `getfile` -> `download`
    > `gettext` -> `readtext`
    > `setbytes` -> `writebytes`
    > `setbinfile` -> `upload`
    > `settext` -> `writetext`
  + Changed
  * Changed default chunk size in `copy_file_data` to 1MB
  * Added `chunk_size` and `options` to `FS.upload`
- Update to version 2.1.3
  + Fixed
  * Incomplete FTPFile.write when using `workers` @geoffjukes
  * Fixed AppFS not creating directory
  + Added
  * Added load_extern switch to opener, fixes #228 @althanos
- Update to version 2.1.2
  + Added
  * Support for Windows NT FTP servers @sspross
  + Fixed
  * Root dir of MemoryFS accesible as a file
  * Packaging issues @televi
  * Deprecation warning re collections.Mapping
- Update to version 2.1.1
  + Added
  * Added PEP 561 py.typed files
  * Use sendfile for faster copies @althonos
  * Atomic exclusive mode in Py2.7 @sqwishy
  + Fixed
  * Fixed lstat @kamomil
- Update to version 2.1.0
  + Added
  * fs.glob support
- Update to version 2.0.27
  + Fixed
  * Fixed for Winows paths #152
  * Fixed ftp dir parsing (@dhirschfeld)
- Update to version 2.0.26
  + Fixed
  * fs.copy and fs.move disable workers if not thread-safe
  * fs.match detects case insensitivity
  * Open in exclusive mode is atomic (@squishy)
  * Exceptions can be pickleabe (@Spacerat)
- Update to version 2.0.25
  + Added
  * workers parameter to fs.copy, fs.move, and fs.mirror for concurrent
    copies
- Update to version 2.0.24
  + Added
  * timeout to FTP opener
- Update to version 2.0.23
  * Fix for Markdown on PyPi, no code changes
- Update to version 2.0.22
  + Fixed
  * Handling of broken unicode on Python2.7
  + Added
  * Added fs.getospath
- Update to version 2.0.21
  + Added
  * Typing information
  * Added Info.suffix, Info.suffixes, Info.stem attributes
  + Fixed
  * Fixed issue with implied directories in TarFS
  + Changed
  * Changed path.splitext so that 'leading periods on the basename are
    ignored', which is the behaviour of os.path.splitext
- Update to version 2.0.20
  + Fixed
  * MultiFS.listdir now correctly filters out duplicates
- Update to version 2.0.19
  + Fixed
  * encoding issue with TarFS
  * CreateFailed now contains the original exception in `exc` attribute
- Update to version 2.0.18
  + Added
  * fs.getfile function
  + Changed
  * Modified walk to use iterators internally (for more efficient walking)
  * Modified fs.copy to use getfile
- Update to version 2.0.17
  + Fixed
  * Issue with ZipFS files missing a byte
- Update to version 2.0.16
  + Added
  * fs.parts
  + Fixed
  * Walk now yields Step named tuples as advertised
  + Added
  * Added max_depth parameter to fs.walk
- Update to version 2.0.15
  + Changed
  * ZipFS files are now seekable (Martin Larralde)
- Update to version 2.0.14
  * No changes, pushed wrong branch to PyPi.
- Update to version 2.0.13
  + Fixed
  * Fixed ignore_errors in walk.py
- Update to version 2.0.12
  + Fixed
  * settext, appendtext, appendbytes, setbytes now raise a TypeError if
    the type is wrong, rather than ValueError
  * More efficient feature detection for FTPFS
  * Fixes for `fs.filesize`
  * Major documentation refactor (Martin Larralde)
- Update to version 2.0.11
  + Added
  * fs.mirror
- Update to version 2.0.10
  + Added
  * Added params support to FS URLs
  + Fixed
  * Many fixes to FTPFS contributed by Martin Larralde.
- Update to version 2.0.9
  + Changed
  * MountFS and MultiFS now accept FS URLS
  * Add openers for AppFS
- Update to version 2.0.8
  + Added
  * Lstat info namespace
  * Link info namespace
  * FS.islink method
  * Info.is_link method
- Update to version 2.0.7
  + Fixes
  * Fixed entry point breaking pip
- Update to version 2.0.6
  + Fixes
  * Opener refinements
- Update to version 2.0.5
  + Fixed
  * Fixed potential for deadlock in MemoryFS
  + Added
  * Added factory parameter to opendir.
  * ClosingSubFS.
  * File objects are all derived from io.IOBase.
  + Fixed
  * Fix closing for FTP opener.
- License change to MIT
- Rebase and update more-relaxed-requirements.patch
- Remove no longer needed python-fs-fix-ftp-test.patch
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Tue Nov 28 2017 bwiedemann@suse.com
- Add python-fs-fix-ftp-test.patch to make ftp tests pass in 2018
* Thu Aug  3 2017 toddrme2178@gmail.com
- Remove no longer needed patches:
  fs-testing-fix-missing-fuse.diff
  fs-testing-fix-missing-paramiko.diff
* Wed Aug  2 2017 sebix+novell.com@sebix.at
- add more-relaxed-requirements.patch to weaken the very harsh version requirements
* Wed Jul 19 2017 sebix+novell.com@sebix.at
- update to version 2.0.4
- update to singlespec
* Mon May  9 2016 hpj@urpla.net
- disable testing of fuse and paramiko dependent parts:
  - fuse tests need root
  - paramiko tests fail
* Sun May  8 2016 hpj@urpla.net
- version 0.5.4: initial build
